@@ -5,14 +5,14 @@ use List::Util 'any';
 use Mojo::Loader ();
 use Mojo::Util 'camelize';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub register {
   my ($plugin, $app, $conf) = @_;
 
   # check if need camelize moniker
-  my $path = $app->home . '/lib/' . $app->moniker;
-  my $moniker = -d $path ? $app->moniker : camelize($app->moniker);
+  my $moniker = camelize($app->moniker);
+  $moniker    = $app->moniker unless -d $app->home . '/lib/' . $moniker;
 
   $app->helper(
     model => sub {
