@@ -1,6 +1,8 @@
 package Lite::Model::Users;
 use Mojo::Base 'MojoX::Model';
 
+sub get { shift->new(@_) }
+
 sub check {
   my ($self, $name) = @_;
 
@@ -8,8 +10,6 @@ sub check {
   return $allow;
 }
 
-sub name {
-  return $_[1] // 'name';
-}
+sub name { return $_[1] // 'name'; }
 
 1;
